pub struct SgemmRequest {
pub a: GpuRef<f32>,
pub b: GpuRef<f32>,
pub c: GpuRef<f32>,
pub m: i32,
pub n: i32,
pub k: i32,
pub alpha: f32,
pub beta: f32,
pub reply: Sender<Result<(), GpuError>>,
}Expand description
Body of a DeviceMsg::Sgemm request. Boxed because it’s larger than
the surrounding enum’s other variants and we want the enum cheap to
clone/send. reply is oneshot, so each request must be unique.
Fields
a: GpuRef<f32>b: GpuRef<f32>c: GpuRef<f32>m: i32n: i32k: i32alpha: f32beta: f32reply: Sender<Result<(), GpuError>>Auto Trait Implementations
impl Freeze for SgemmRequest
impl !RefUnwindSafe for SgemmRequest
impl Send for SgemmRequest
impl Sync for SgemmRequest
impl Unpin for SgemmRequest
impl UnsafeUnpin for SgemmRequest
impl !UnwindSafe for SgemmRequest